@@ -2,6 +2,7 @@
 context("available tutorials")
 
 test_that("Tutorial names are retrieved", {
+  local_edition(3)
 
   expect_error(available_tutorials("not a package"), "No package found")
   expect_error(available_tutorials("base"), "No tutorials found")
@@ -13,20 +14,5 @@ test_that("Tutorial names are retrieved", {
   expect_error(run_tutorial("doesn't exist", package = "learnr"), "Available ")
   expect_message(run_tutorial(package = "learnr"), "Available ")
 
-
-  expect_output(
-    fixed = TRUE,
-    print(available_tutorials("learnr")),
-"Available tutorials:
-* learnr
-  - ex-data-basics    : \"Data basics\"
-  - ex-data-filter    : \"Filter observations\"
-  - ex-data-mutate    : \"Create new variables\"
-  - ex-data-summarise : \"Summarise Tables\"
-  - ex-setup-r        : \"Set Up\"
-  - hello             : \"Hello, Tutorial!\"
-  - quiz_question     : \"Tutorial Quiz Questions in `learnr`\"
-  - slidy             : \"Slidly demo\""
-  )
-
+  expect_snapshot(available_tutorials("learnr"))
 })
